summaryrefslogtreecommitdiff
path: root/src/rmd_capture_audio.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/rmd_capture_audio.h')
-rw-r--r--src/rmd_capture_audio.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/rmd_capture_audio.h b/src/rmd_capture_audio.h
index b403fa8..a55ea8c 100644
--- a/src/rmd_capture_audio.h
+++ b/src/rmd_capture_audio.h
@@ -24,19 +24,19 @@
* For further information contact me at johnvarouhakis@gmail.com *
******************************************************************************/
-#ifndef CAPTURE_SOUND_H
-#define CAPTURE_SOUND_H 1
+#ifndef CAPTURE_AUDIO_H
+#define CAPTURE_AUDIO_H 1
#include "rmd_types.h"
/**
* Sound capturing thread. Data are placed on a
* list to be picked up by other threads.
*
* \param pdata ProgData struct containing all program data
*/
-void *rmdCaptureSound(ProgData *pdata);
+void *rmdCaptureAudio(ProgData *pdata);
#endif
© All Rights Reserved
@@ -24,19 +24,19 @@
#include "rmd_types.h"
/**
-* Sound capturing thread. Data are placed on a
+* Audio capturing thread. Data are placed on a
* list to be picked up by other threads.
*